@@ -1,13 +1,13 @@
 ##
 ## copied from the Rsymphony package from
 ## Kurt Hornik and Stefan Theussl and Reinhard Harter
-## 
+##
 ## Simple functions for converting "matrix" type objects into the
 ## sparse "column major order" (CSC, modulo offsets) format used by
 ## SYMPHONY.
 
 ## matind: vector of the row indices corresponding to each entry of
-##   value 
+##   value
 ## values: vector of the values of nonzero entries of the constraint
 ##   matrix in column order.
 
@@ -16,8 +16,8 @@ make_csc_matrix <- function(x) UseMethod("make_csc_matrix")
 make_csc_matrix.matrix <- function(x) {
     if(!is.matrix(x))
         stop("Argument 'x' must be a matrix.")
-   
-    ind <- which(x != 0, arr.ind = TRUE)    
+
+    ind <- which(x != 0, arr.ind = TRUE)
     list(matbeg = c(0L, cumsum(tabulate(ind[, 2L], ncol(x)))),
          matind = ind[, 1] - 1L,
          values = x[ind])
@@ -36,3 +36,28 @@ make_csc_matrix.simple_triplet_matrix <- function(x) {
          values = x$v[ind])
 }
 
+## Added by @bnaras for sparse symmetric matrix.
+
+make_csc_symm_matrix <- function(x) UseMethod("make_csc_symm_matrix")
+
+make_csc_symm_matrix.matrix  <- function(m) {
+  ind <- which(m!=0 ,arr.ind = TRUE)
+  ind  <- ind[ind[, 1] <= ind[, 2], ] ## keep upper part only
+  values  <- m[ind]
+  x  <- list(i = ind[, 1], j = ind[, 2])  ## triplet form
+  ind  <- order(x$j, x$i)  ## may not be needed
+  list(matbeg = c(0L, cumsum(tabulate(x$j[ind], ncol(m)))),
+       matind = x$i[ind] - 1L,
+       values = values)
+}
+
+make_csc_symm_matrix.simple_triplet_matrix  <- function(m) {
+  ind <- which(m$i <= m$j)
+  x <- list(i = m$i[ind] + 1L, j = m$j[ind] + 1L) ##make it 1-based
+  values <- m$v[ind]
+  ind  <- order(x$j, x$i)  ## may not be needed
+  list(matbeg = c(0L, cumsum(tabulate(x$j[ind], m$ncol))),
+       matind = x$i[ind] - 1L,
+       values = values)
+}
+
